@@ -573,7 +573,7 @@ sub get_smotif_definition {
 
 =head1 NAME
 
-SmotifTF Template-free Modeling Method
+SmotifTF Template-free Modeling Method - The pre-requisites
 
 =head1 SYNOPSIS
 
@@ -589,11 +589,11 @@ present in a centralized local directory or a user-designated separate directory
 
 Software / data:
 
-1. Psipred
+1. Psipred (http://bioinf.cs.ucl.ac.uk/psipred/)
 
-2. HHSuite 
+2. HHSuite (ftp://toolkit.genzentrum.lmu.de/pub/HH-suite/)
 
-3. psi-blast and delta-blast
+3. Psiblast and Delta-blast (http://blast.ncbi.nlm.nih.gov/Blast.cgi?PAGE_TYPE=BlastDocs&DOC_TYPE=Download)
 
 4. Modeller (version 9.14 https://salilab.org/modeller/)
 
@@ -601,26 +601,32 @@ Software / data:
 
 Download and install the above mentioned software / data according to their instructions. 
 
+Note: Psipred and Psiblast require legacy blast and Delta-blast is a part of the Blast+ package. 
+
+Databases required: 
+
+1. PDBAA blast database is required (ftp://ftp.ncbi.nlm.nih.gov/blast/db/). 
+2. HHsuite databases NR20 and PDB70 are required (ftp://toolkit.genzentrum.lmu.de/pub/HH-suite/databases/hhsuite_dbs/)
+
 SmotifTF Download and Installation: 
 
-The following components need to be downloaded and
-installed to run SmotifTF: 
+Download SmotifTF package from CPAN: 
 
-1. The software from CPAN (http://)
+http://search.cpan.org/dist/SmotifTF/
 
 Installation of the software (also available in the README file):
 
-	tar -zxvf SmotifTF-0.01.tar.gz
+ tar -zxvf SmotifTF-0.01.tar.gz
 
-	cd SmotifTF-0.01/
+ cd SmotifTF-0.01/
 
-	perl Makefile.PL PREFIX=/home/user/SmotifTF-0.01
+ perl Makefile.PL PREFIX=/home/user/SmotifTF-0.01
 
-	make
+ make
 
-	make test
+ make test
 
-	make install
+ make install
 
 Set up the configuration file:
 
@@ -634,21 +640,21 @@ Set environment varible in .bashrc file:
 export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
 
 
+ Pre-requisites steps: 
 
-	Modeling algorithm steps: 
-
-    	 ----------------------------------------------------
-	    |Step 0:				                             |
-	    |	Run Pre-requisites			                     |
-	    |	Psipred, HHblits+HHsearch, Psiblast, Delta-blast |
-		|													 |
-	    |	Single-core job		     	                     |
-	    |	Usage: 
-		|   perl smotiftf_prereq.pl --sequence_file=4uzx.fasta --dir=4uzx --step=all
-	     ----------------------------------------------------
+      -------------------------------------------------------
+     | Run Pre-requisites:                                   |
+     | Psipred, HHblits+HHsearch, Psiblast, Delta-blast      |
+     |                                                       |
+     | Single-core job                                       |
+     | Usage:                                                |
+     |   perl smotiftf_prereq.pl --sequence_file=1zzz.fasta  |
+     |         --dir=1zzz --step=all                         |
+      -------------------------------------------------------
 
 
-How to run the program:
+How to run the pre-requisites program:
+
 
 1. Create a subdirectory with a dummy pdb file name (eg: 1abc or 1zzz). 
 
@@ -660,14 +666,9 @@ How to run the program:
 4. Run the pre-requisites step first. This runs Psipred, HHblits+HHsearch,
    Psiblast and Delta-blast. It will then generate the dynamic database of
    Smotifs and the list of putative Smotifs in the query protein.
-   perl smotiftf_prereq.pl --step=all --pdb=1zzz --chain=A --dir=1zzz 
+   Usage: perl smotiftf_prereq.pl --sequence_file=1zzz.fasta --dir=1zzz --step=all
 
-5. Run smotiftf.pl according to instructions. 
-
-Results: 
-
-Top 5 models are stored in the subdirectory (1abc or 1zzz) as:
-Model.1.pdb, Model.2.pdb, Model.3.pdb, Model.4.pdb & Model.5.pdb	
+5. Next, run smotiftf.pl according to the instructions given there.  
 
 Reference: 
 
@@ -693,20 +694,15 @@ Prints the manual page and exits.
 
 =item B<--step>
 
-1,2,3,4,5,6 or all
+1,2,3,4,5,6,7,8 or all
 
-=item B<--pdb>
+=item B<--sequence_file>
+ 
+Give the name of the fasta file. 
 
-Give 4-letter dummy pdb_code
+=item B<--dir>
 
-=item B<--chain>
-
-Give 1-letter chain_id
-
-=item B<--havestructure>
-
-0 or 1 depending on whether a structure is known for the protein from
-alternate sources. 
+Give 4-letter dummy pdb_code or any other directory where the fasta file is present. 
 
 =back
 
